package ru.ldeloff.servermonitorbot.service;

import com.jcraft.jsch.JSch;
import com.jcraft.jsch.JSchException;
import com.jcraft.jsch.Session;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import ru.ldeloff.servermonitorbot.config.SshConfig;
import ru.ldeloff.servermonitorbot.model.SshServer;

import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class SshServiceImpl implements SshService{

    private final List<SshServer> sshServers;

    @Autowired
    public SshServiceImpl(SshConfig sshConfig) {
        this.sshServers = sshConfig.getServers();
    }

    private List<Session> sessions = new ArrayList<>();

    @Override
    public void ConnectToAllServer() {
        sshServers.forEach(sshServer -> {
            try {
                Session session = ConnectToServer(sshServer);
                log.info("Успешно подключён к " + sshServer.getHost());
                sessions.add(session);
            } catch (JSchException e) {
                log.warn("Не удалось соединиться с " + sshServer.getHost() + ": " + e.getMessage());
            }
        });
    }

    @Override
    public Session ConnectToServer(SshServer sshServer) throws JSchException {
        Session session = new JSch().getSession(sshServer.getUser(),
                sshServer.getHost(),
                sshServer.getPort());
        session.setPassword(sshServer.getPassword());
        session.setConfig("StrictHostKeyChecking", "no");
        session.connect();
        return session;
    }
}
